--- base/sys_info_posix.cc
+++ base/sys_info_posix.cc
@@ -14,7 +14,7 @@
 #include <gdk/gdk.h>
 #endif
 
-#if defined(OS_OPENBSD)
+#if defined(OS_OPENBSD) || defined(OS_FREEBSD)
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #endif
@@ -55,9 +55,15 @@ int64 SysInfo::AmountOfPhysicalMemory() {
 #if defined(OS_FREEBSD)
   // _SC_PHYS_PAGES is not part of POSIX and not available on OS X or
   // FreeBSD
-  // TODO(benl): I have no idea how to get this
-  NOTIMPLEMENTED();
-  return 0;
+  static int pages, page_size;
+  size_t size = sizeof(pages);
+  sysctlbyname("vm.stats.vm.v_page_count", &pages, &size, NULL, 0);
+  sysctlbyname("vm.stats.vm.v_page_size", &page_size, &size, NULL, 0);
+  if (pages == -1 || page_size == -1) {
+    NOTREACHED();
+    return 0;
+  }
+  return static_cast<int64>(pages) * page_size;
 #else
   long pages = sysconf(_SC_PHYS_PAGES);
   long page_size = sysconf(_SC_PAGE_SIZE);
@@ -171,6 +177,13 @@ size_t SysInfo::MaxSharedMemorySize() {
 
   return limit;
 }
+#elif defined(OS_FREEBSD)
+size_t SysInfo::MaxSharedMemorySize() {
+  static size_t limit;
+  size_t size = sizeof(limit);
+  sysctlbyname("kern.ipc.shmmax", &limit, &size, NULL, 0);
+  return limit;
+}
 #endif
 
 }  // namespace base
diff --git base/test/test_file_util_posix.cc base/test/test_file_util_posix.cc
index 8f7d69d..9fe8da3 100644
